==> lhcsmapi-1.3.229.tar.gz: lhcsmapi-1.3.229/test/test_analysis/hwc/rq/test_RqCircuitQuery.py <==
import unittest
import pandas as pd
import numpy as np

from lhcsmapi.analysis.RqCircuitQuery import RqCircuitQuery
from test.test_analysis.hwc.read_csv import read_csv


class TestRqCircuitQuery(unittest.TestCase):
    def test_create_report_analysis_template(self):
        # arrange
        source_timestamp_qds_rq_df = pd.DataFrame({'source': {0: '16L2'},
                                                   'timestamp': {0: 1544622149598000000}})
        source_timestamp_nqps_rqd_df = pd.DataFrame({'source': {0: 'B17L2'},
                                                     'timestamp': {0: 1544622149613000000}})
        timestamp_fgc_rqd = 1544622149620000000
        i_meas_rqd_df = read_csv('rq', 'i_meas_rqf_df')
        i_meas_rqf_df = read_csv('rq', 'i_meas_rqf_df')
        author = 'mmacieje'
        rqd_query = RqCircuitQuery('RQ', 'RQD.A12')

        # act
        results_act = rqd_query.create_report_analysis_template(source_timestamp_qds_rq_df,
                                                                     source_timestamp_nqps_rqd_df,
                                                                     timestamp_fgc_rqd, i_meas_rqd_df, i_meas_rqf_df,
                                                                     author=author)

        results_act['lhcsmapi_version'] = '1.3.226'
        # assert
        results_ref = pd.DataFrame({'circuit': {0: 'RQ.A12'}, 'timestamp_pic_rqd': {0: np.nan},
                                    'timestamp_pic_rqf': {0: np.nan}, 'timestamp_fgc_rqd': {0: np.nan},
                                    'timestamp_fgc_rqf': {0: np.nan}, 'timestamp_ee_rqd': {0: np.nan},
                                    'timestamp_ee_rqf': {0: np.nan}, 'timestamp_leads_rqd': {0: np.nan},
                                    'timestamp_leads_rqf': {0: np.nan}, 'datetime_fgc': {0: '2018-12-12 14:42:29.620'},
                                    'timestamp_iqps': {0: '2018-12-12 14:42:29.598'},
                                    'timestamp_nqps': {0: 1544622149613000000}, 'iqps_or_nqps_trigger': {0: 'iQPS'},
                                    'I_MEAS_RQD_quench': {0: 11154}, 'I_MEAS_RQF_quench': {0: 11154},
                                    'magnet': {0: '16L2'}, 'nqps_crate': {0: 'B17L2'}, 'origin': {0: ''},
                                    'dU_QS0/dt': {0: np.nan}, 'QH': {0: ''}, 'R_DIODE_LEADS_RQD': {0: np.nan},
                                    'R_DIODE_LEADS_RQF': {0: np.nan}, 'nqps_db': {0: 'PM'}, 'comments': {0: ''},
                                    'performed_by': {0: 'mmacieje'}, 'lhcsmapi_version': {0: '1.3.226'}})

        results_act.fillna(np.nan, inplace=True)
        pd.testing.assert_frame_equal(results_ref, results_act)

==> lhcsmapi-1.3.271.tar.gz: lhcsmapi-1.3.271/test/test_analysis/hwc/rq/test_RqCircuitQuery.py <==
import unittest
import pandas as pd
import numpy as np

from lhcsmapi.analysis.RqCircuitQuery import RqCircuitQuery
from test.test_analysis.hwc.read_csv import read_csv


class TestRqCircuitQuery(unittest.TestCase):
    def test_create_report_analysis_template(self):
        # arrange
        source_timestamp_qds_rq_df = pd.DataFrame({'source': {0: '16L2'},
                                                   'timestamp': {0: 1544622149598000000}})
        source_timestamp_nqps_rqd_df = pd.DataFrame({'source': {0: 'B17L2'},
                                                     'timestamp': {0: 1544622149613000000}})
        timestamp_fgc_rqd = 1544622149620000000
        timestamp_fgc_rqf = 1544622149620000000
        i_meas_rqd_df = read_csv('rq', 'i_meas_rqf_df')
        i_meas_rqf_df = read_csv('rq', 'i_meas_rqf_df')
        author = 'mmacieje'
        rqd_query = RqCircuitQuery('RQ', 'RQD.A12')

        # act
        results_act = rqd_query.create_report_analysis_template(source_timestamp_qds_rq_df,
                                                                source_timestamp_nqps_rqd_df, timestamp_fgc_rqd,
                                                                timestamp_fgc_rqf, i_meas_rqd_df, i_meas_rqf_df,
                                                                author=author)
        results_act['lhcsmapi_version'] = '1.3.226'

        # assert
        results_ref = pd.DataFrame({'circuit': {0: 'RQ.A12'}, 'timestamp_pic_rqd': {0: np.nan},
                                    'timestamp_pic_rqf': {0: np.nan}, 'timestamp_fgc_rqd': {0: np.nan},
                                    'timestamp_fgc_rqf': {0: np.nan}, 'timestamp_ee_rqd': {0: np.nan},
                                    'timestamp_ee_rqf': {0: np.nan}, 'timestamp_leads_rqd': {0: np.nan},
                                    'timestamp_leads_rqf': {0: np.nan}, 'datetime_fgc': {0: '2018-12-12 14:42:29.620'},
                                    'timestamp_iqps': {0: 1544622149598000000},
                                    'datetime_iqps': {0: '2018-12-12 14:42:29.598'},
                                    'dt_quench': {0: 0.0}, 'timestamp_nqps': {0: 1544622149613000000},
                                    'datetime_nqps': {0: '2018-12-12 14:42:29.613'},
                                    'iqps_or_nqps_trigger': {0: 'iQPS'},
                                    'I_MEAS_RQD_quench': {0: 11154}, 'I_MEAS_RQF_quench': {0: 11154},
                                    'magnet': {0: '16L2'}, 'nqps_crate': {0: 'B17L2'}, 'origin': {0: np.nan},
                                    'dU_QS0/dt': {0: np.nan}, 'QH': {0: np.nan}, 'R_DIODE_LEADS_RQD': {0: np.nan},
                                    'R_DIODE_LEADS_RQF': {0: np.nan}, 'nqps_db': {0: 'PM'}, 'comments': {0: np.nan},
                                    'performed_by': {0: 'mmacieje'}, 'lhcsmapi_version': {0: '1.3.226'}})

        results_act.fillna(np.nan, inplace=True)
        pd.testing.assert_frame_equal(results_ref, results_act)
